@@ -6,9 +6,9 @@ function(noflevels, row.no, zerobased=FALSE) {
         stop("There cannot be more than ", max.combs, " rows.\n\n", call. = FALSE)
         }
     
-    if (!zerobased) row.no <- row.no - 1
-    col.no <- length(noflevels)
+    if (!zerobased) {row.no <- row.no - 1}
+    
     mbase <- c(rev(cumprod(rev(noflevels))), 1)[-1]
-    sapply(1:col.no, function(x) floor(row.no/mbase[x])%%noflevels[x])
-}
+    sapply(seq(length(noflevels)), function(x) floor(row.no/mbase[x])%%noflevels[x])
+    }
 
